
## CATO-CLI - mutation.site.removeSiteBwLicense:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeSiteBwLicense) for documentation on this operation.

### Usage for mutation.site.removeSiteBwLicense:

`catocli mutation site removeSiteBwLicense -h`

`catocli mutation site removeSiteBwLicense <json>`

`catocli mutation site removeSiteBwLicense "$(cat < removeSiteBwLicense.json)"`

`catocli mutation site removeSiteBwLicense '{"removeSiteBwLicenseInput": {"licenseId": {"licenseId": "ID"}, "siteRefInput": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}'`

#### Operation Arguments for mutation.site.removeSiteBwLicense ####
`accountId` [ID] - (required) N/A 
`removeSiteBwLicenseInput` [RemoveSiteBwLicenseInput] - (required) N/A 
